==> csound_6.14.0~dfsg.orig.tar.xz: csound-6.14.0/README.md <==
# CSOUND
Version 6.14.0

[![Build Status](https://travis-ci.org/csound/csound.svg?branch=develop)](https://travis-ci.org/csound/csound)
[![Build status](https://ci.appveyor.com/api/projects/status/1qamc986774rsbjq/branch/develop?svg=true)](https://ci.appveyor.com/project/csound/csound/branch/develop)
<!--- ![Coverity Status](https://scan.coverity.com/projects/1822/badge.svg) --->
A sound and music computing system.

Csound is copyright (c) 1991-2020 The Csound Developers, see CONTRIBUTORS

Csound is free software; you can redistribute them
and/or modify them under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

Csound is distributed in the hope that they will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this software; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
02110-1301 USA

# GETTING STARTED

This repository contains the code for the core Csound library, the
interfaces library, and the command-line interface frontend. It also
contains specific code for ports to various embedded, mobile and web platforms.

For general project information, please look at http://csound.com,
where all details about Csound, what it does, its history, music
made with it, and many other things can be found.

The Csound Reference Manual can be found online at http://docs.csound.com.

The Csound API application programming interface reference 
may be found online at http://csound.github.io/docs/api/index.html.

Information on how to build Csound on various platforms is given in
the BUILD.md file at the top level directory of this repository.

Information about build pipelines with Azure and Github actions is given in
[DockerFiles/Readme.md](DockerFiles/ReadMe.md).

# CONTRIBUTORS

Csound contains contributions from musicians, scientists, and programmers
from around the world. They include (but are not limited to):

* Allan Lee
* Andres Cabrera
* Anthony Kozar
* Barry Vercoe
* Bill Gardner
* Bill Verplank
* Dan Ellis
* David Macintyre
* Ed Costello
* Eli Breder
* Fabio P. Bertolotti
* Felipe Sataler
* Gabriel Maldonado
* Greg Sullivan
* Hans Mikelson
* Henri Manson
* Ian McCurdy
* Istvan Varga
* Jean Piché
* Joachim Heintz
* John Ramsdell
* John ffitch
* Marc Resibois
* Mark Dolson
* Matt Ingalls
* Max Mathews
* Michael Casey
* Michael Clark
* Michael Gogins
* Mike Berry
* Nate Whetsell
* Paris Smaragdis
* Perry Cook
* Peter Neubäcker
* Peter Nix
* Rasmus Ekman
* Richard Dobson
* Richard Karpen
* Rob Shaw
* Robin Whittle
* Rory Walsh
* Sean Costello
* Stephen Kyne
* Steven Yi
* Tito Latini
* Tom Erbe
* Victor Lazzarini
* Ville Pulkki

==> csound_6.17.0~dfsg.orig.tar.xz: csound-6.17.0/README.md <==
# CSOUND
Version 6.17.0 (beta)

![Build Status](https://github.com/csound/csound/actions/workflows/csound_builds.yml/badge.svg?branch=develop)
<!--- ![Coverity Status](https://scan.coverity.com/projects/1822/badge.svg) --->
A sound and music computing system.

Csound is copyright (c) 1991-2020 The Csound Developers, see CONTRIBUTORS

Csound is free software; you can redistribute them
and/or modify them under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

Csound is distributed in the hope that they will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this software; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
02110-1301 USA

# GETTING STARTED

This repository contains the code for the core Csound library, the
interfaces library, and the command-line interface frontend. It also
contains specific code for ports to various embedded, mobile and web platforms.

For general project information, please look at http://csound.com,
where all details about Csound, what it does, its history, music
made with it, and many other things can be found.

The Csound Reference Manual can be found online at http://docs.csound.com.

The Csound API application programming interface reference 
may be found online at http://csound.github.io/docs/api/index.html.

Information on how to build Csound on various platforms is given in
the BUILD.md file at the top level directory of this repository.

Information about build pipelines with Azure and Github actions is given in
[DockerFiles/Readme.md](DockerFiles/ReadMe.md).

# CONTRIBUTORS

Csound contains contributions from musicians, scientists, and programmers
from around the world. They include (but are not limited to):

* Allan Lee
* Andres Cabrera
* Anthony Kozar
* Barry Vercoe
* Bill Gardner
* Bill Verplank
* Dan Ellis
* David Macintyre
* Ed Costello
* Eli Breder
* Fabio P. Bertolotti
* Felipe Sataler
* François Pinot
* Gabriel Maldonado
* Greg Sullivan
* Hans Mikelson
* Henri Manson
* Ian McCurdy
* Istvan Varga
* Jean Piché
* Joachim Heintz
* John Ramsdell
* John ffitch
* Marc Resibois
* Mark Dolson
* Matt Ingalls
* Max Mathews
* Michael Casey
* Michael Clark
* Michael Gogins
* Mike Berry
* Nate Whetsell
* Paris Smaragdis
* Perry Cook
* Peter Neubäcker
* Peter Nix
* Rasmus Ekman
* Richard Dobson
* Richard Karpen
* Rob Shaw
* Robin Whittle
* Rory Walsh
* Sean Costello
* Stephen Kyne
* Steven Yi
* Tito Latini
* Tom Erbe
* Victor Lazzarini
* Ville Pulkki
